%define anolis_release 4
%bcond_without weak_modules
%bcond_without dist_conf

Name:		kmod
Version:	30
Release:	%{anolis_release}%{?dist}
Summary:	Linux kernel module management utilities

License:	GPLv2+
URL:		https://git.kernel.org/pub/scm/utils/kernel/kmod/kmod.git
Source0:	https://www.kernel.org/pub/linux/utils/kernel/kmod/%{name}-%{version}.tar.xz
Source1:	weak-modules
Source2:	depmod.conf.dist
Exclusiveos:	Linux

# Upstream patches
Patch1: 0001-testsuite-repair-read-of-uninitialized-memory.patch
Patch2: 0002-build-enable-building-running-tests-from-a-subdir.patch
Patch3: 0003-testsuite-fix-override-of-stat-on-32-bit-architectur.patch
Patch4: 0004-libkmod-do-not-crash-on-unknown-signature-algorithm.patch

BuildRequires:  gcc
BuildRequires:	chrpath
BuildRequires:	zlib-devel
BuildRequires:	xz-devel
BuildRequires:  libxslt
BuildRequires:  openssl-devel
BuildRequires:  make
BuildRequires:  libzstd-devel
BuildRequires:  gtk-doc
BuildRequires:  libtool

Provides:	module-init-tools = 4.0
Obsoletes:	module-init-tools < 4.0
Provides:	/sbin/modprobe

%if %{with weak_modules}
Provides:	/usr/sbin/weak-modules
%endif

%description
The kmod package provides various programs needed for automatic
loading and unloading of modules under 2.6, 3.x, and later kernels, as well
as other module management programs. Device drivers and filesystems are two
examples of loaded and unloaded modules.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package	libs
Summary:	Libraries to handle kernel module loading and unloading
License:	LGPLv2+

%description	libs
The kmod-libs package provides runtime libraries for any application that
wishes to load or unload Linux kernel modules from the running system.

%package	devel
Summary:	Header files for kmod development
Requires:	%{name}-libs = %{version}-%{release}

%description	devel
The kmod-devel package provides header files used for development of
applications that wish to load or unload Linux kernel modules.

%prep
%autosetup -n %{name}-%{version} -p1

%build

%configure \
  --with-openssl \
  --with-zlib \
  --with-xz \
  --with-zstd \
  --enable-debug

%{make_build} V=1

%install
%{make_install}

pushd $RPM_BUILD_ROOT%{_mandir}/man5
ln -s modprobe.d.5.gz modprobe.conf.5.gz
popd

find %{buildroot} -type f -name "*.la" -delete

mkdir -p $RPM_BUILD_ROOT%{_sbindir}
ln -sf ../bin/kmod $RPM_BUILD_ROOT%{_sbindir}/modprobe
ln -sf ../bin/kmod $RPM_BUILD_ROOT%{_sbindir}/modinfo
ln -sf ../bin/kmod $RPM_BUILD_ROOT%{_sbindir}/insmod
ln -sf ../bin/kmod $RPM_BUILD_ROOT%{_sbindir}/rmmod
ln -sf ../bin/kmod $RPM_BUILD_ROOT%{_sbindir}/depmod
ln -sf ../bin/kmod $RPM_BUILD_ROOT%{_sbindir}/lsmod

mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/modprobe.d
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/depmod.d
mkdir -p $RPM_BUILD_ROOT%{_prefix}/lib/modprobe.d

%if %{with weak_modules}
install -pm 755 %{SOURCE1} $RPM_BUILD_ROOT%{_sbindir}/weak-modules
%endif

%if %{with dist_conf}
install -m 0644 %{SOURCE2} $RPM_BUILD_ROOT%{_sysconfdir}/depmod.d/dist.conf
%endif

%generate_compatibility_deps

%files
%dir %{_sysconfdir}/depmod.d
%dir %{_sysconfdir}/modprobe.d
%dir %{_prefix}/lib/modprobe.d
%{_bindir}/kmod
%{_sbindir}/modprobe
%{_sbindir}/modinfo
%{_sbindir}/insmod
%{_sbindir}/rmmod
%{_sbindir}/lsmod
%{_sbindir}/depmod
%{abidir}/kmod-option.list
%if %{with weak_modules}
%{_sbindir}/weak-modules
%{abidir}/weak-modules-option.list
%endif
%{_datadir}/bash-completion/
%if %{with dist_conf}
%{_sysconfdir}/depmod.d/dist.conf
%endif
%attr(0644,root,root) %{_mandir}/man5/*.5*
%attr(0644,root,root) %{_mandir}/man8/*.8*

%files doc
%doc NEWS README.md TODO

%files libs
%dir %{abidir}
%license COPYING
%{_libdir}/libkmod.so.*
%{abidir}/libkmod.dump

%files devel
%{_includedir}/libkmod.h
%{_libdir}/pkgconfig/libkmod.pc
%{_libdir}/libkmod.so

%changelog
* Fri Jun 16 2023 happy_orange <songnannan@linux.alibaba.com> - 30-4
- enable weak_modules and enabled dist_conf

* Mon Dec 26 2022 Jing Zhang <renyu.zj@linux.alibaba.com> - 30-3
- repair read of uninitialized memory and fix crash bugs etc.

* Tue Oct 25 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 30-2
- optimise spec file

* Mon Sep 26 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 30-1
- update to 30

* Thu Mar 10 2022 zhang xianting <zhangxianting@uniontech.com> - 29-1
- Initial build for Anolis V23
